@@ -4,21 +4,21 @@ localized = True
 
 
 class Provider(BaseProvider):
-    city_suffixes: ElementsType = ["Ville"]
-    street_suffixes: ElementsType = ["Street"]
-    city_formats: ElementsType = ("{{first_name}} {{city_suffix}}",)
-    street_name_formats: ElementsType = ("{{last_name}} {{street_suffix}}",)
-    street_address_formats: ElementsType = ("{{building_number}} {{street_name}}",)
-    address_formats: ElementsType = ("{{street_address}} {{postcode}} {{city}}",)
-    building_number_formats: ElementsType = ("##",)
-    postcode_formats: ElementsType = ("#####",)
-    countries: ElementsType = [tz["name"] for tz in date_time.Provider.countries]
+    city_suffixes: ElementsType[str] = ["Ville"]
+    street_suffixes: ElementsType[str] = ["Street"]
+    city_formats: ElementsType[str] = ("{{first_name}} {{city_suffix}}",)
+    street_name_formats: ElementsType[str] = ("{{last_name}} {{street_suffix}}",)
+    street_address_formats: ElementsType[str] = ("{{building_number}} {{street_name}}",)
+    address_formats: ElementsType[str] = ("{{street_address}} {{postcode}} {{city}}",)
+    building_number_formats: ElementsType[str] = ("##",)
+    postcode_formats: ElementsType[str] = ("#####",)
+    countries: ElementsType[str] = [country.name for country in date_time.Provider.countries]
 
     ALPHA_2 = "alpha-2"
     ALPHA_3 = "alpha-3"
 
-    alpha_2_country_codes: ElementsType = [tz["alpha-2-code"] for tz in date_time.Provider.countries]
-    alpha_3_country_codes: ElementsType = [tz["alpha-3-code"] for tz in date_time.Provider.countries]
+    alpha_2_country_codes: ElementsType[str] = [country.alpha_2_code for country in date_time.Provider.countries]
+    alpha_3_country_codes: ElementsType[str] = [country.alpha_3_code for country in date_time.Provider.countries]
 
     def city_suffix(self) -> str:
         """
@@ -92,7 +92,7 @@ class Provider(BaseProvider):
     def current_country(self) -> str:
         current_country_code = self.current_country_code()
         current_country = [
-            tz["name"] for tz in date_time.Provider.countries if tz["alpha-2-code"] == current_country_code
+            country.name for country in date_time.Provider.countries if country.alpha_2_code == current_country_code
         ]
         if len(current_country) == 1:
             return current_country[0]  # type: ignore
