@@ -156,7 +156,7 @@ class Provider(BaseProvider):
         )
     )
 
-    safe_colors: ElementsType = (
+    safe_colors: ElementsType[str] = (
         "black",
         "maroon",
         "green",
@@ -174,13 +174,13 @@ class Provider(BaseProvider):
         "white",
     )
 
-    def color_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
+    def color_name(self) -> str:
         """Generate a color name."""
-        return self.random_element(self.all_colors.keys(), min_length, max_length)
+        return self.random_element(self.all_colors.keys())
 
-    def safe_color_name(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
+    def safe_color_name(self) -> str:
         """Generate a web-safe color name."""
-        return self.random_element(self.safe_colors, min_length, max_length)
+        return self.random_element(self.safe_colors)
 
     def hex_color(self) -> str:
         """Generate a color formatted as a hex triplet."""
